package cn.yyxx.eyuangame.core.impl.center

import android.app.Dialog
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Handler
import android.os.Looper
import android.os.Message
import android.text.TextUtils
import android.view.Gravity
import android.view.View
import android.view.Window
import android.view.WindowManager
import android.widget.Button
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import cn.yyxx.eyuangame.core.entity.ResultInfo
import cn.yyxx.eyuangame.core.entity.SdkBackLoginInfo
import cn.yyxx.eyuangame.core.ext.setThrottleListener
import cn.yyxx.eyuangame.core.impl.SdkBridgeImpl
import cn.yyxx.eyuangame.core.internal.IImplCallback
import cn.yyxx.eyuangame.core.internal.IRequestCallback
import cn.yyxx.eyuangame.core.network.SdkRequest
import cn.yyxx.eyuangame.core.ui.EventEditText
import cn.yyxx.eyuangame.core.utils.countDownCoroutines
import cn.yyxx.support.DensityUtils
import cn.yyxx.support.ResUtils
import cn.yyxx.support.hawkeye.ToastUtils
import kotlinx.coroutines.Job
import org.json.JSONObject

/**
 * @author #Suyghur.
 * Created on 2021/12/23
 */
class BindEmailContainer(context: Context, private val callback: IImplCallback) : Dialog(context) {
    private lateinit var llGroup: LinearLayout
    private lateinit var clTips: ConstraintLayout

    private lateinit var ivReturn: ImageView
    private lateinit var eetEmail: EventEditText
    private lateinit var eetCaptcha: EventEditText
    private lateinit var btnCaptCha: Button
    private lateinit var btnConfirm: Button
    private lateinit var tvBindTips: TextView

    private val handler = object : Handler(Looper.getMainLooper()) {
        override fun handleMessage(msg: Message) {
            if (msg.what == 101) {
                changeTimeView(msg.obj as Int)
            }
        }
    }

    private var job: Job? = null

    init {
        setCanceledOnTouchOutside(true)
        window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        requestWindowFeature(Window.FEATURE_NO_TITLE)
        initView(context)
    }

    private fun initView(context: Context) {
        setContentView(ResUtils.getResId(context, "yyxx_member_bind_email", "layout"))

        val attr = window?.attributes as WindowManager.LayoutParams
        attr.height = DensityUtils.dip2px(context, 250f)
        if (SdkBridgeImpl.isLand) {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] / 2
        } else {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] - 80
        }
        attr.gravity = Gravity.CENTER


        ivReturn = findViewById(ResUtils.getResId(context, "yyxx_iv_return", "id"))

        ivReturn.setOnClickListener {
            dismiss()

        }

        llGroup = findViewById(ResUtils.getResId(context, "yyxx_ll_group", "id"))
        clTips = findViewById(ResUtils.getResId(context, "yyxx_cl_tips", "id"))

        eetEmail = findViewById(ResUtils.getResId(context, "yyxx_eet_email", "id"))
        eetEmail.editText.hint = ResUtils.getResString(context, "yyxx_hint_email")
        eetEmail.leftImageView.visibility = View.VISIBLE
        eetEmail.leftImageView.setBackgroundResource(ResUtils.getResId(context, "yyxx_email2_img", "drawable"))

        eetCaptcha = findViewById(ResUtils.getResId(context, "yyxx_eet_captcha", "id"))
        eetCaptcha.editText.hint = ResUtils.getResString(context, "yyxx_hint_bind_phone_captcha")

        btnCaptCha = findViewById(ResUtils.getResId(context, "yyxx_btn_captcha", "id"))
        btnCaptCha.setThrottleListener {
            callGetCaptcha()
        }

        btnConfirm = findViewById(ResUtils.getResId(context, "yyxx_btn_confirm", "id"))
        btnConfirm.setThrottleListener {
            callBindEmail()
        }

        tvBindTips = findViewById(ResUtils.getResId(context, "yyxx_tv_tips2", "id"))
        tvBindTips.text = if (SdkBackLoginInfo.instance.email.length > 6) {
            val head = SdkBackLoginInfo.instance.email.substring(0, 3)
            val index = SdkBackLoginInfo.instance.email.indexOf("@")
            val foot = SdkBackLoginInfo.instance.email.substring(index, SdkBackLoginInfo.instance.email.length)
            "${head}xxxx${foot}"
        } else {
            SdkBackLoginInfo.instance.email
        }
        showOrHideTips()
    }


    private fun callGetCaptcha() {
        val email = eetEmail.editText.text.trim().toString()

        if (TextUtils.isEmpty(email)) {
            ToastUtils.toastInfo(context, ResUtils.getResString(context, "yyxx_tips_email_format_error"))
            return
        }

        try {
            with(JSONObject()) {
                put("sms_type", "bind")
                put("email", email)
                SdkRequest.instance.getEmailCaptcha(context, this, object : IRequestCallback {
                    override fun onResponse(resultInfo: ResultInfo) {
                        if (resultInfo.code == 1) {
                            ToastUtils.toastInfo(context, resultInfo.msg)
                            changeTimeNum()
                        } else {
                            ToastUtils.toastInfo(context, resultInfo.msg)
                        }
                    }
                })
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    private fun callBindEmail() {
        val email = eetEmail.editText.text.trim().toString()
        val captcha = eetCaptcha.editText.text.trim().toString()

        if (TextUtils.isEmpty(captcha)) {
            ToastUtils.toastInfo(context, ResUtils.getResString(context, "yyxx_tips_captcha_format_error"))
            return
        }

        if (TextUtils.isEmpty(email)) {
            ToastUtils.toastInfo(context, ResUtils.getResString(context, "yyxx_tips_email_format_error"))
            return
        }

        try {
            with(JSONObject()) {
                put("uid", SdkBackLoginInfo.instance.userId)
                put("email", email)
                put("sms_code", captcha)
                SdkRequest.instance.bindEmail(context, this, object : IRequestCallback {
                    override fun onResponse(resultInfo: ResultInfo) {
                        if (resultInfo.code == 1) {
                            SdkBackLoginInfo.instance.email = email
                            ToastUtils.toastInfo(context, resultInfo.msg)
                            callback.onResult(0, resultInfo.msg)
                            dismiss()
                        } else {
                            ToastUtils.toastInfo(context, resultInfo.msg)
                        }
                    }
                })
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    private fun changeTimeView(time: Int) {
        btnCaptCha.apply {
            text = if (time <= 0) {
                this.isEnabled = true
                ResUtils.getResString(context, "yyxx_tv_get_captcha")
            } else {
                this.isEnabled = false
                "${time}s"
            }
        }
    }

    private fun changeTimeNum() {
        job?.apply {
            cancel()
            job = null
        }
        job = countDownCoroutines(60,
            { second ->
                with(btnCaptCha) {
                    isEnabled = false
                    text = "${second}s"
                }
            }, {
                btnCaptCha.isEnabled = true
                with(btnCaptCha) {
                    isEnabled = true
                    text = ResUtils.getResString(context, "yyxx_tv_get_captcha")
                }
            })
    }

    private fun showOrHideTips() {
        if (TextUtils.isEmpty(SdkBackLoginInfo.instance.email)) {
            llGroup.visibility = View.VISIBLE
            eetEmail.visibility = View.VISIBLE
            btnConfirm.visibility = View.VISIBLE
            clTips.visibility = View.GONE
        } else {
            llGroup.visibility = View.GONE
            eetEmail.visibility = View.GONE
            btnConfirm.visibility = View.GONE
            clTips.visibility = View.VISIBLE
        }
    }

    override fun dismiss() {
        super.dismiss()
        job?.apply {
            cancel()
            job = null
        }
    }
}