package cn.yyxx.eyuangame.core.ui.dialog

import android.app.Dialog
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.view.*
import android.widget.*
import androidx.viewpager.widget.PagerAdapter
import cn.yyxx.eyuangame.core.impl.SdkBridgeImpl
import cn.yyxx.eyuangame.core.ui.EventEditText
import cn.yyxx.eyuangame.core.ui.NoScrollViewPager
import cn.yyxx.support.DensityUtils
import cn.yyxx.support.ResUtils
import com.google.android.material.tabs.TabLayout

/**
 * @author #Suyghur.
 * Created on 2021/06/23
 */
class ForgetPwdDialog(context: Context, private val isLandscape: Boolean) :
    Dialog(context, ResUtils.getResId(context, "EYuanGameTheme", "style")) {

    private lateinit var viewPager: NoScrollViewPager
    private lateinit var tabLayout: TabLayout
    private lateinit var pagerAdapter: DialogPagerAdapter
    private lateinit var phoneContainer: View
    private lateinit var emailContainer: View

    lateinit var ivReturn: ImageView
    lateinit var eetPhoneAccount: EventEditText
        private set
    lateinit var tvArea: TextView
    lateinit var ivArrow: ImageView
    lateinit var eetPhone: EventEditText
        private set
    lateinit var btnPhoneConfirm: Button

    private lateinit var rlAreaList: RelativeLayout
    private lateinit var llAreaList: LinearLayout
    private lateinit var svAreaList: ScrollView

    private var imgUp = 0
    private var imgDown = 0

    var code = ""
        private set

    lateinit var eetEmailAccount: EventEditText
        private set
    lateinit var eetEmail: EventEditText
        private set
    lateinit var btnEmailConfirm: Button

    private val areaCodeList: MutableList<String> = mutableListOf()

    init {
        setCanceledOnTouchOutside(false)
        window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        requestWindowFeature(Window.FEATURE_NO_TITLE)
        initView(context)
    }

    private fun initView(context: Context) {

        val view: View = LayoutInflater.from(context).inflate(ResUtils.getResId(context, "yyxx_forget_pwd_dialog", "layout"), null)

        setContentView(view)

        val attr = window?.attributes as WindowManager.LayoutParams
        //设置dialog 在布局中的位置
        attr.height = ViewGroup.LayoutParams.WRAP_CONTENT
        if (isLandscape) {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] / 2
        } else {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] - 80
        }
        attr.gravity = Gravity.CENTER

        viewPager = view.findViewById(ResUtils.getResId(context, "yyxx_vp", "id"))
        tabLayout = view.findViewById(ResUtils.getResId(context, "yyxx_tl", "id"))

        ivReturn = view.findViewById(ResUtils.getResId(context, "yyxx_iv_return", "id"))
        ivReturn.setOnClickListener {
            dismiss()
        }

        phoneContainer = View.inflate(context, ResUtils.getResId(context, "yyxx_forget_pwd_phone_container", "layout"), null)

        imgUp = ResUtils.getResId(context, "yyxx_pack_up_white_img", "drawable")
        imgDown = ResUtils.getResId(context, "yyxx_pack_down_white_img", "drawable")

        eetPhoneAccount = phoneContainer.findViewById(ResUtils.getResId(context, "yyxx_eet_account", "id"))
        eetPhoneAccount.leftImageView.setBackgroundResource(ResUtils.getResId(context, "yyxx_account_img", "drawable"))
        eetPhoneAccount.leftImageView.visibility = View.VISIBLE
        eetPhoneAccount.editText.setHint(ResUtils.getResId(context, "yyxx_hint_account", "string"))

        tvArea = phoneContainer.findViewById(ResUtils.getResId(context, "yyxx_tv_area", "id"))
        ivArrow = phoneContainer.findViewById(ResUtils.getResId(context, "yyxx_iv_arrow", "id"))
        ivArrow.setOnClickListener {
            changeAreaList()
        }

        eetPhone = phoneContainer.findViewById(ResUtils.getResId(context, "yyxx_eet_phone", "id"))
        eetPhone.editText.setHint(ResUtils.getResId(context, "yyxx_hint_phone", "string"))

        rlAreaList = phoneContainer.findViewById(ResUtils.getResId(context, "yyxx_rl_area_list", "id"))
        rlAreaList.visibility = View.GONE
        llAreaList = phoneContainer.findViewById(ResUtils.getResId(context, "yyxx_ll_area_list", "id"))
        svAreaList = phoneContainer.findViewById(ResUtils.getResId(context, "yyxx_sv_area_list", "id"))

        btnPhoneConfirm = phoneContainer.findViewById(ResUtils.getResId(context, "yyxx_btn_confirm", "id"))
        autoFillAreaList(context)

        emailContainer = View.inflate(context, ResUtils.getResId(context, "yyxx_forget_pwd_email_container", "layout"), null)

        eetEmailAccount = emailContainer.findViewById(ResUtils.getResId(context, "yyxx_eet_account", "id"))
        eetEmailAccount.leftImageView.setBackgroundResource(ResUtils.getResId(context, "yyxx_account_img", "drawable"))
        eetEmailAccount.leftImageView.visibility = View.VISIBLE
        eetEmailAccount.editText.setHint(ResUtils.getResId(context, "yyxx_hint_account", "string"))

        eetEmail = emailContainer.findViewById(ResUtils.getResId(context, "yyxx_eet_email", "id"))
        eetEmail.leftImageView.setBackgroundResource(ResUtils.getResId(context, "yyxx_email2_img", "drawable"))
        eetEmail.leftImageView.visibility = View.VISIBLE
        eetEmail.editText.setHint(ResUtils.getResId(context, "yyxx_hint_email", "string"))

        btnEmailConfirm = emailContainer.findViewById(ResUtils.getResId(context, "yyxx_btn_confirm", "id"))

        val views = mutableListOf(
            phoneContainer,
            emailContainer
        )

        val tabs = context.resources.getStringArray(ResUtils.getResId(context, "yyxx_forget_pwd_tab", "array"))

        pagerAdapter = DialogPagerAdapter(views, tabs)

        viewPager.adapter = pagerAdapter
        tabLayout.setupWithViewPager(viewPager)
        tabLayout.setTabsFromPagerAdapter(pagerAdapter)
    }

    private fun autoFillAreaList(context: Context) {
        if (SdkBridgeImpl.initBean.areaCodeList.isNullOrEmpty()) {
            //默认4个地区
            areaCodeList.add("86")
            //香港
            areaCodeList.add("852")
            //澳门
            areaCodeList.add("853")
            //台湾
            areaCodeList.add("886")
        } else {
            SdkBridgeImpl.initBean.areaCodeList.forEach {
                areaCodeList.add(it)
            }
        }
        initAreaList(context)
    }

    private fun initAreaList(context: Context) {
        llAreaList.removeAllViews()
        //单行高
        var height = 100
        tvArea.apply {
            height = if (layoutParams != null) {
                layoutParams!!.height
            } else {
                100
            }
        }
        //ScrollView高度
        var maxHeight = 0
        areaCodeList.apply {
            maxHeight = if (size < 2) {
                size * height
            } else {
                2 * height
            }
        }
        //循环添加列
        areaCodeList.apply {
            for (i in indices) {
                val areaCode = this[i]
                //添加线
                val line = View(context)
                line.layoutParams = LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, 2)
                line.setBackgroundColor(Color.parseColor("#E6FFFFFF"))
                llAreaList.apply {
                    if (childCount > 0) {
                        addView(line)
                    }
                }
                //添加区号
                val item = LayoutInflater.from(context).inflate(ResUtils.getResId(context, "yyxx_area_list_item", "layout"), null)
                item?.apply {
                    val tvAreaCode = findViewById<TextView>(ResUtils.getResId(context, "yyxx_tv_area", "id"))
                    tvAreaCode.gravity = Gravity.CENTER
                    tvAreaCode.text = areaCode
                    setOnClickListener(OnItemClick(areaCode))
                    layoutParams = LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, height)
                    llAreaList.addView(this, llAreaList.childCount)
                }
            }
        }
        svAreaList.layoutParams = RelativeLayout.LayoutParams(RelativeLayout.LayoutParams.MATCH_PARENT, maxHeight)
    }

    private fun changeAreaList() {
        if (rlAreaList.visibility == View.GONE) {
            ivArrow.setBackgroundResource(imgUp)
            rlAreaList.visibility = View.VISIBLE
        } else {
            ivArrow.setBackgroundResource(imgDown)
            rlAreaList.visibility = View.GONE
        }
    }


    override fun dismiss() {
        super.dismiss()
        areaCodeList.clear()
        rlAreaList.visibility = View.GONE
    }

    /**
     * 账号列表item点击事件
     */
    private inner class OnItemClick(val areaCode: String) : View.OnClickListener {
        override fun onClick(v: View?) {
            tvArea.apply {
                changeAreaList()
                tvArea.text = areaCode
                code = areaCode
            }
        }
    }

    private class DialogPagerAdapter(private val views: MutableList<View>, private val titles: Array<String>) : PagerAdapter() {
        override fun getCount(): Int {
            return views.size
        }

        override fun getPageTitle(position: Int): CharSequence {
            return titles[position]
        }

        override fun isViewFromObject(view: View, `object`: Any): Boolean {
            return view == `object`
        }

        override fun instantiateItem(container: ViewGroup, position: Int): Any {
            val view = views[position]
            container.addView(view)
            return view
        }

        override fun destroyItem(container: ViewGroup, position: Int, `object`: Any) {
            container.removeView(`object` as View)
        }
    }

}